.. _api_reference:

QuickApp public API reference
================================

.. py:module:: quickapp


Example function
---------------------

.. autofunction:: contract

.. autofunction:: decorate


